@@ -1,5 +1,3 @@
-# -*- mode: cperl; tab-width: 8; indent-tabs-mode: nil; basic-offset: 2 -*-
-# vim:ts=8:sw=2:et:sta:sts=2
 package Module::Build::ModuleInfo;
 
 # This module provides routines to gather information about
@@ -7,36 +5,33 @@ package Module::Build::ModuleInfo;
 # parrot future to look at other types of modules).
 
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.3500_01';
-$VERSION = eval $VERSION;
 
 use File::Spec;
 use IO::File;
 use Module::Build::Version;
 
 
-my $PKG_REGEXP  = qr{   # match a package declaration
+my $PKG_REGEXP  = qr/   # match a package declaration
   ^[\s\{;]*             # intro chars on a line
   package               # the word 'package'
   \s+                   # whitespace
   ([\w:]+)              # a package name
   \s*                   # optional whitespace
   ;                     # semicolon line terminator
-}x;
+/x;
 
-my $VARNAME_REGEXP = qr{ # match fully-qualified VERSION name
+my $VARNAME_REGEXP = qr/ # match fully-qualified VERSION name
   ([\$*])         # sigil - $ or *
   (
     (             # optional leading package name
-      (?:::|\')?  # possibly starting like just :: (  la $::VERSION)
+      (?:::|\')?  # possibly starting like just :: (ala $::VERSION)
       (?:\w+(?:::|\'))*  # Foo::Bar:: ...
     )?
     VERSION
   )\b
-}x;
+/x;
 
-my $VERS_REGEXP = qr{ # match a VERSION definition
+my $VERS_REGEXP = qr/ # match a VERSION definition
   (?:
     \(\s*$VARNAME_REGEXP\s*\) # with parens
   |
@@ -44,45 +39,43 @@ my $VERS_REGEXP = qr{ # match a VERSION definition
   )
   \s*
   =[^=~]  # = but not ==, nor =~
-}x;
+/x;
 
 
 sub new_from_file {
-  my $class    = shift;
+  my $package  = shift;
   my $filename = File::Spec->rel2abs( shift );
-
   return undef unless defined( $filename ) && -f $filename;
-  return $class->_init(undef, $filename, @_);
+  return $package->_init( undef, $filename, @_ );
 }
 
 sub new_from_module {
-  my $class   = shift;
+  my $package = shift;
   my $module  = shift;
   my %props   = @_;
-
   $props{inc} ||= \@INC;
-  my $filename = $class->find_module_by_name( $module, $props{inc} );
+  my $filename = $package->find_module_by_name( $module, $props{inc} );
   return undef unless defined( $filename ) && -f $filename;
-  return $class->_init($module, $filename, %props);
+  return $package->_init( $module, $filename, %props );
 }
 
 sub _init {
-  my $class    = shift;
+  my $package  = shift;
   my $module   = shift;
   my $filename = shift;
-  my %props = @_;
 
+  my %props = @_;
   my( %valid_props, @valid_props );
   @valid_props = qw( collect_pod inc );
   @valid_props{@valid_props} = delete( @props{@valid_props} );
   warn "Unknown properties: @{[keys %props]}\n" if scalar( %props );
 
   my %data = (
-    module       => $module,
-    filename     => $filename,
-    version      => undef,
-    packages     => [],
-    versions     => {},
+    module   => $module,
+    filename => $filename,
+    version  => undef,
+    packages => [],
+    versions => {},
     pod          => {},
     pod_headings => [],
     collect_pod  => 0,
@@ -90,22 +83,20 @@ sub _init {
     %valid_props,
   );
 
-  my $self = bless(\%data, $class);
+  my $self = bless( \%data, $package );
 
   $self->_parse_file();
 
-  unless($self->{module} and length($self->{module})) {
-    my ($v, $d, $f) = File::Spec->splitpath($self->{filename});
-    if($f =~ /\.pm$/) {
+  unless ( $self->{module} && length( $self->{module} ) ) {
+    my( $v, $d, $f ) = File::Spec->splitpath( $self->{filename} );
+    if ( $f =~ /\.pm$/ ) {
       $f =~ s/\..+$//;
       my @candidates = grep /$f$/, @{$self->{packages}};
-      $self->{module} = shift(@candidates); # punt
-    }
-    else {
-      if(grep /main/, @{$self->{packages}}) {
-        $self->{module} = 'main';
-      }
-      else {
+      $self->{module} = shift( @candidates ); # punt
+    } else {
+      if ( grep /main/, @{$self->{packages}} ) {
+	$self->{module} = 'main';
+      } else {
         $self->{module} = $self->{packages}[0] || '';
       }
     }
@@ -119,7 +110,7 @@ sub _init {
 
 # class method
 sub _do_find_module {
-  my $class   = shift;
+  my $package = shift;
   my $module  = shift || die 'find_module_by_name() requires a package name';
   my $dirs    = shift || \@INC;
 
@@ -172,12 +163,6 @@ sub _parse_file {
   my $fh = IO::File->new( $filename )
     or die( "Can't open '$filename': $!" );
 
-  $self->_parse_fh($fh);
-}
-
-sub _parse_fh {
-  my ($self, $fh) = @_;
-
   my( $in_pod, $seen_end, $need_vers ) = ( 0, 0, 0 );
   my( @pkgs, %vers, %pod, @pod );
   my $pkg = 'main';
@@ -185,16 +170,12 @@ sub _parse_fh {
   my $pod_data = '';
 
   while (defined( my $line = <$fh> )) {
-    my $line_num = $.;
 
     chomp( $line );
     next if $line =~ /^\s*#/;
 
     $in_pod = ($line =~ /^=(?!cut)/) ? 1 : ($line =~ /^=cut/) ? 0 : $in_pod;
 
-    # Would be nice if we could also check $in_string or something too
-    last if !$in_pod && $line =~ /^__(?:DATA|END)__$/;
-
     if ( $in_pod || $line =~ /^=cut/ ) {
 
       if ( $line =~ /^=head\d\s+(.+)\s*$/ ) {
@@ -231,16 +212,14 @@ sub _parse_fh {
 	push( @pkgs, $vers_pkg ) unless grep( $vers_pkg eq $_, @pkgs );
 	$need_vers = 0 if $vers_pkg eq $pkg;
 
+	my $v =
+	  $self->_evaluate_version_line( $vers_sig, $vers_fullname, $line );
 	unless ( defined $vers{$vers_pkg} && length $vers{$vers_pkg} ) {
-	  $vers{$vers_pkg} = 
-	    $self->_evaluate_version_line( $vers_sig, $vers_fullname, $line );
+	  $vers{$vers_pkg} = $v;
 	} else {
-	  # Warn unless the user is using the "$VERSION = eval
-	  # $VERSION" idiom (though there are probably other idioms
-	  # that we should watch out for...)
-	  warn <<"EOM" unless $line =~ /=\s*eval/;
-Package '$vers_pkg' already declared with version '$vers{$vers_pkg}',
-ignoring subsequent declaration on line $line_num.
+	  warn <<"EOM";
+Package '$vers_pkg' already declared with version '$vers{$vers_pkg}'
+ignoring new version '$v'.
 EOM
 	}
 
@@ -252,7 +231,7 @@ EOM
 	$vers{$pkg} = $v;
 	push( @pkgs, 'main' );
 
-      # first non-comment line in undeclared package defines package main
+      # first non-comement line in undeclared packge defines package main
       } elsif ( !exists($vers{main}) && $pkg eq 'main' && $line =~ /\w+/ ) {
 	$need_vers = 1;
 	$vers{main} = '';
@@ -270,7 +249,7 @@ EOM
 	} else {
 	  warn <<"EOM";
 Package '$pkg' already declared with version '$vers{$pkg}'
-ignoring new version '$v' on line $line_num.
+ignoring new version '$v'.
 EOM
 	}
 
@@ -290,48 +269,32 @@ EOM
   $self->{pod_headings} = \@pod;
 }
 
-{
-my $pn = 0;
 sub _evaluate_version_line {
   my $self = shift;
   my( $sigil, $var, $line ) = @_;
 
   # Some of this code came from the ExtUtils:: hierarchy.
 
-  # We compile into $vsub because 'use version' would cause
-  # compiletime/runtime issues with local()
-  my $vsub;
-  $pn++; # everybody gets their own package
-  my $eval = qq{BEGIN { q#  Hide from _packages_inside()
-    #; package Module::Build::ModuleInfo::_version::p$pn;
-    use Module::Build::Version;
-    no strict;
+  my $eval = qq{q#  Hide from _packages_inside()
+		 #; package Module::Build::ModuleInfo::_version;
+		 no strict;
 
-    local $sigil$var;
-    \$$var=undef;
-      \$vsub = sub {
-        $line;
-        \$$var
-      };
-  }};
+		 local $sigil$var;
+		 \$$var=undef; do {
+		   $line
+		 }; \$$var
+		};
 
   local $^W;
-  # Try to get the $VERSION
-  eval $eval;
-  warn "Error evaling version line '$eval' in $self->{filename}: $@\n"
-    if $@;
-  (ref($vsub) eq 'CODE') or
-    die "failed to build version sub for $self->{filename}";
-  my $result = eval { $vsub->() };
-
-  die "Could not get version from $self->{filename} by executing:\n$eval\n\nThe fatal error was: $@\n" if $@;
+  # Try and get the $VERSION
+  my $result = eval $eval;
+  warn "Error evaling version line '$eval' in $self->{filename}: $@\n" if $@;
 
   # Bless it into our own version class
   $result = Module::Build::Version->new($result);
 
   return $result;
 }
-}
 
 
 ############################################################
@@ -371,11 +334,9 @@ sub pod {
 
 __END__
 
-=for :stopwords ModuleInfo
-
 =head1 NAME
 
-ModuleInfo - Gather package and POD information from a perl module file
+ModuleInfo - Gather package and POD information from a perl module files
 
 
 =head1 DESCRIPTION
@@ -384,16 +345,16 @@ ModuleInfo - Gather package and POD information from a perl module file
 
 =item new_from_file($filename, collect_pod => 1)
 
-Construct a C<ModuleInfo> object given the path to a file. Takes an optional
-argument C<collect_pod> which is a boolean that determines whether
+Construct a ModuleInfo object given the path to a file. Takes an optional
+arguement C<collect_pod> which is a boolean that determines whether
 POD data is collected and stored for reference. POD data is not
 collected by default. POD headings are always collected.
 
 =item new_from_module($module, collect_pod => 1, inc => \@dirs)
 
-Construct a C<ModuleInfo> object given a module or package name. In addition
+Construct a ModuleInfo object given a module or package name. In addition
 to accepting the C<collect_pod> argument as described above, this
-method accepts a C<inc> argument which is a reference to an array of
+method accepts a C<inc> arguemnt which is a reference to an array of
 of directories to search for the module. If none are given, the
 default is @INC.
 
@@ -434,7 +395,7 @@ Returns the POD data in the given section.
 =item find_module_by_name($module, \@dirs)
 
 Returns the path to a module given the module or package name. A list
-of directories can be passed in as an optional parameter, otherwise
+of directories can be passed in as an optional paramater, otherwise
 @INC is searched.
 
 Can be called as either an object or a class method.
@@ -443,7 +404,7 @@ Can be called as either an object or a class method.
 
 Returns the entry in C<@dirs> (or C<@INC> by default) that contains
 the module C<$module>. A list of directories can be passed in as an
-optional parameter, otherwise @INC is searched.
+optional paramater, otherwise @INC is searched.
 
 Can be called as either an object or a class method.
 
@@ -452,12 +413,12 @@ Can be called as either an object or a class method.
 
 =head1 AUTHOR
 
-Ken Williams <kwilliams@cpan.org>, Randy W. Sims <RandyS@ThePierianSpring.org>
+Ken Williams <ken@cpan.org>, Randy W. Sims <RandyS@ThePierianSpring.org>
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2006 Ken Williams.  All rights reserved.
+Copyright (c) 2001-2005 Ken Williams.  All rights reserved.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
